# kmviz

![GitHub Release](https://img.shields.io/github/v/release/tlemane/kmviz?style=for-the-badge&logo=github)
![PyPI - Version](https://img.shields.io/pypi/v/kmviz?style=for-the-badge&color=blue&logo=pypi)
![Docker Image Version](https://img.shields.io/docker/v/tlemane/kmviz?style=for-the-badge&logo=docker&label=docker%20hub&color=blue)

![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/tlemane/kmviz/ci.yml?style=for-the-badge&logo=github&label=kmviz-ci)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kmviz?style=for-the-badge&logo=python)

**kmviz** is a user-friendly web interface for interacting with biological sequence indexes. In a nutshell, it connects to multiple, local or distant, sequence indexes to performs sequence queries. Results can then be explored through *`tables`*, *`plots`*, *`sequence views`*, or even *`maps`* when metadata contains geographical information. Note that representations are fully customizable allowing to make production-grade figures.

:warning: **kmviz** is a work in progress!

See [kmviz documentation](https://tlemane.github.io/kmviz).


